@@ -1,6 +1,6 @@
-import json
 import logging
 
+import borgmatic.actions.json
 import borgmatic.borg.rinfo
 import borgmatic.config.validate
 
@@ -8,7 +8,13 @@ logger = logging.getLogger(__name__)
 
 
 def run_rinfo(
-    repository, storage, local_borg_version, rinfo_arguments, local_path, remote_path,
+    repository,
+    config,
+    local_borg_version,
+    rinfo_arguments,
+    global_arguments,
+    local_path,
+    remote_path,
 ):
     '''
     Run the "rinfo" action for the given repository.
@@ -18,15 +24,19 @@ def run_rinfo(
     if rinfo_arguments.repository is None or borgmatic.config.validate.repositories_match(
         repository, rinfo_arguments.repository
     ):
-        if not rinfo_arguments.json:  # pragma: nocover
-            logger.answer('{}: Displaying repository summary information'.format(repository))
+        if not rinfo_arguments.json:
+            logger.answer(
+                f'{repository.get("label", repository["path"])}: Displaying repository summary information'
+            )
+
         json_output = borgmatic.borg.rinfo.display_repository_info(
-            repository,
-            storage,
+            repository['path'],
+            config,
             local_borg_version,
             rinfo_arguments=rinfo_arguments,
+            global_arguments=global_arguments,
             local_path=local_path,
             remote_path=remote_path,
         )
-        if json_output:  # pragma: nocover
-            yield json.loads(json_output)
+        if json_output:
+            yield borgmatic.actions.json.parse_json(json_output, repository.get('label'))
